| Name                      | Version     | License                                                 | URL                                                                                                    |
|---------------------------|-------------|---------------------------------------------------------|--------------------------------------------------------------------------------------------------------|
| Jinja2                    | 3.1.6       | BSD License                                             | https://github.com/pallets/jinja/                                                                      |
| MarkupSafe                | 3.0.2       | BSD License                                             | https://github.com/pallets/markupsafe/                                                                 |
| PyYAML                    | 6.0.3       | MIT License                                             | https://pyyaml.org/                                                                                    |
| Pygments                  | 2.19.1      | BSD License                                             | https://pygments.org                                                                                   |
| arrow                     | 1.4.0       | Apache Software License                                 | https://github.com/arrow-py/arrow                                                                      |
| asttokens                 | 3.0.0       | Apache 2.0                                              | https://github.com/gristlabs/asttokens                                                                 |
| attrs                     | 25.4.0      | MIT                                                     | https://www.attrs.org/en/stable/changelog.html                                                         |
| beartype                  | 0.22.9      | MIT License                                             | UNKNOWN                                                                                                |
| boolean.py                | 5.0         | BSD-2-Clause                                            | https://github.com/bastikr/boolean.py                                                                  |
| chardet                   | 5.2.0       | GNU Lesser General Public License v2 or later (LGPLv2+) | https://github.com/chardet/chardet                                                                     |
| click                     | 8.2.2       | BSD-3-Clause                                            | https://github.com/pallets/click/                                                                      |
| cyclonedx-python-lib      | 11.6.0      | Apache Software License                                 | https://github.com/CycloneDX/cyclonedx-python-lib/#readme                                              |
| decorator                 | 5.2.1       | BSD License                                             | UNKNOWN                                                                                                |
| defusedxml                | 0.7.1       | Python Software Foundation License                      | https://github.com/tiran/defusedxml                                                                    |
| executing                 | 2.2.0       | MIT License                                             | https://github.com/alexmojaki/executing                                                                |
| fqdn                      | 1.5.1       | Mozilla Public License 2.0 (MPL 2.0)                    | https://github.com/ypcrts/fqdn                                                                         |
| idna                      | 3.11        | BSD-3-Clause                                            | https://github.com/kjd/idna                                                                            |
| init-mater-project        | 0.2.0       | GNU Lesser General Public License v3 (LGPLv3)           | https://gricad-gitlab.univ-grenoble-alpes.fr/isterre-dynamic-modeling/mater-project/init-mater-project |
| ipython                   | 9.2.0       | BSD License                                             | https://ipython.org                                                                                    |
| ipython_pygments_lexers   | 1.1.1       | BSD License                                             | https://github.com/ipython/ipython-pygments-lexers                                                     |
| isoduration               | 20.11.0     | ISC License (ISCL)                                      | https://github.com/bolsote/isoduration                                                                 |
| jedi                      | 0.19.2      | MIT License                                             | https://github.com/davidhalter/jedi                                                                    |
| jsonpointer               | 3.0.0       | BSD License                                             | https://github.com/stefankoegl/python-json-pointer                                                     |
| jsonschema                | 4.25.1      | MIT                                                     | https://github.com/python-jsonschema/jsonschema                                                        |
| jsonschema-specifications | 2025.9.1    | MIT                                                     | https://github.com/python-jsonschema/jsonschema-specifications                                         |
| lark                      | 1.3.1       | MIT License                                             | https://github.com/lark-parser/lark                                                                    |
| license-expression        | 30.4.4      | Apache-2.0                                              | https://github.com/aboutcode-org/license-expression                                                    |
| lxml                      | 6.0.2       | BSD-3-Clause                                            | https://lxml.de/                                                                                       |
| matplotlib-inline         | 0.1.7       | BSD License                                             | https://github.com/ipython/matplotlib-inline                                                           |
| packageurl-python         | 0.17.6      | MIT License                                             | https://github.com/package-url/packageurl-python                                                       |
| packaging                 | 25.0        | Apache Software License; BSD License                    | https://github.com/pypa/packaging                                                                      |
| parso                     | 0.8.4       | MIT License                                             | https://github.com/davidhalter/parso                                                                   |
| pexpect                   | 4.9.0       | ISC License (ISCL)                                      | https://pexpect.readthedocs.io/                                                                        |
| pip-requirements-parser   | 32.0.1      | MIT                                                     | https://github.com/nexB/pip-requirements-parser                                                        |
| ply                       | 3.11        | BSD                                                     | http://www.dabeaz.com/ply/                                                                             |
| prompt_toolkit            | 3.0.51      | BSD License                                             | UNKNOWN                                                                                                |
| ptyprocess                | 0.7.0       | ISC License (ISCL)                                      | https://github.com/pexpect/ptyprocess                                                                  |
| pure_eval                 | 0.2.3       | MIT License                                             | http://github.com/alexmojaki/pure_eval                                                                 |
| py-serializable           | 2.1.0       | Apache Software License                                 | https://github.com/madpah/serializable#readme                                                          |
| pyparsing                 | 3.3.1       | MIT                                                     | https://github.com/pyparsing/pyparsing/                                                                |
| python-dateutil           | 2.9.0.post0 | Apache Software License; BSD License                    | https://github.com/dateutil/dateutil                                                                   |
| rdflib                    | 7.5.0       | BSD License                                             | https://github.com/RDFLib/rdflib                                                                       |
| referencing               | 0.37.0      | MIT                                                     | https://github.com/python-jsonschema/referencing                                                       |
| rfc3339-validator         | 0.1.4       | MIT License                                             | https://github.com/naimetti/rfc3339-validator                                                          |
| rfc3986-validator         | 0.1.1       | MIT License                                             | https://github.com/naimetti/rfc3986-validator                                                          |
| rfc3987-syntax            | 1.1.0       | MIT                                                     | https://github.com/willynilly/rfc3987-syntax                                                           |
| rpds-py                   | 0.30.0      | MIT                                                     | https://github.com/crate-py/rpds                                                                       |
| ruff                      | 0.11.11     | MIT License                                             | https://docs.astral.sh/ruff                                                                            |
| semantic-version          | 2.10.0      | BSD License                                             | https://github.com/rbarrois/python-semanticversion                                                     |
| six                       | 1.17.0      | MIT License                                             | https://github.com/benjaminp/six                                                                       |
| sortedcontainers          | 2.4.0       | Apache Software License                                 | http://www.grantjenks.com/docs/sortedcontainers/                                                       |
| stack-data                | 0.6.3       | MIT License                                             | http://github.com/alexmojaki/stack_data                                                                |
| traitlets                 | 5.14.3      | BSD License                                             | https://github.com/ipython/traitlets                                                                   |
| typing_extensions         | 4.15.0      | PSF-2.0                                                 | https://github.com/python/typing_extensions                                                            |
| tzdata                    | 2025.3      | Apache-2.0                                              | https://github.com/python/tzdata                                                                       |
| uri-template              | 1.3.0       | MIT License                                             | https://gitlab.linss.com/open-source/python/uri-template                                               |
| uritools                  | 6.0.1       | MIT                                                     | https://github.com/tkem/uritools/                                                                      |
| webcolors                 | 25.10.0     | BSD License                                             | UNKNOWN                                                                                                |
| xmltodict                 | 1.0.2       | MIT License                                             | https://github.com/martinblech/xmltodict                                                               |
